@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: kwatch.cpp,v 1.10 2003/02/16 15:03:30 mj Exp $
+ * $Id: kwatch.cpp,v 1.12 2004/02/28 20:14:31 mj Exp $
  *
  * Class for kwatch application
  *
@@ -66,7 +66,7 @@
 
 
 kwatch::kwatch()
-    : KMainWindow( 0, i18n("KDE Logfile Viewer") ),
+    : KMainWindow(0, i18n("KDE Logfile Viewer")),
       m_popup(0), m_log(0), m_prefs(0)
 {
     // initialize
@@ -95,7 +95,7 @@ kwatch::kwatch()
     show();
 
     // log startup
-    logtime(i18n("kwatch started"));
+    //logtime(i18n("kwatch started"));
 }
 
 
@@ -137,7 +137,6 @@ void kwatch::setupActions()
 
     // right button popup
     m_popup = (QPopupMenu *)factory()->container("rb_popup", this);
-    
 }
 
 
