@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: kwatchconf.cpp,v 1.6 2003/02/16 15:03:30 mj Exp $
+ * $Id: kwatchconf.cpp,v 1.7 2004/06/22 20:26:27 mj Exp $
  *
  * Configuration parameters of the application
  *
@@ -62,6 +62,7 @@ void kwatchConf::save(KConfig *config)
     config->writeEntry("EnableLog" , enableLog);
     config->writeEntry("SoundCall" , soundCall);
     config->writeEntry("SoundLog"  , soundLog);
+    config->writeEntry("IdleTimout", idleTimeout);
     config->sync();
 }
 
@@ -90,5 +91,6 @@ void kwatchConf::read(KConfig *config)
     soundCall  = config->readPathEntry ("SoundCall");
     enableLog  = config->readBoolEntry ("EnableLog" ,DEFAULT_ENABLELOG);
     soundLog   = config->readPathEntry ("SoundLog");
+    idleTimeout= config->readNumEntry  ("IdleTimeout", DEFAULT_IDLETIMEOUT);
     
 }
