@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: kwatchconf.h,v 1.5 2003/02/16 15:03:30 mj Exp $
+ * $Id: kwatchconf.h,v 1.6 2004/06/22 20:26:27 mj Exp $
  *
  * Configuration parameters of the application
  *
@@ -69,6 +69,7 @@ public:
     bool	enableLog;
     QString	soundCall;
     QString	soundLog;
+    int		idleTimeout;
     
 public:
     // read/save config
@@ -93,6 +94,7 @@ public:
 #define DEFAULT_SHOWMENU	true
 #define DEFAULT_ENABLECALL	true
 #define DEFAULT_ENABLELOG	true
+#define DEFAULT_IDLETIMEOUT	300
 
 
 #endif /**KWATCHCONF_H**/
