@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: main.cpp,v 0.16 2003/02/16 15:03:30 mj Exp $
+ * $Id: main.cpp,v 0.20 2004/07/05 20:56:09 mj Exp $
  *
  * kwatch main()
  *
@@ -36,7 +36,6 @@
  * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *****************************************************************************/
 
-
 #include <kapp.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -47,7 +46,7 @@
 
 
 static const char *description = I18N_NOOP("KDE Log File Viewer");
-static const char *version = "2.3.1";
+static const char *version = "2.3.3";
 
 
 
@@ -56,9 +55,9 @@ int main(int argc, char **argv)
     KAboutData about("kwatch",
 		     I18N_NOOP("kwatch"),
 		     version, description,
-		     KAboutData::License_GPL, "(C) 2000-2003 Martin Junius");
+		     KAboutData::License_GPL, "(C) 2000-2004 Martin Junius");
     about.addAuthor("Martin Junius", "Main Developer",
-		    "mj@m-j-s.net", "http://www.m-j-s.net/kde/");
+		    "mj\x40n0ll.net", "http://www.m-j-s.net/kde/");
     KCmdLineArgs::init(argc, argv, &about);
     KApplication app;
 
